import { LuciaError } from "../../error.js";
export const getUserByProviderIdFunction = (auth) => {
    const getUserByProviderId = async (provider, identifier) => {
        const providerId = `${provider}:${identifier}`;
        const databaseUser = await auth.configs.adapter.getUserByProviderId(providerId);
        if (!databaseUser)
            throw new LuciaError("AUTH_INVALID_PROVIDER_ID");
        const user = auth.configs.transformUserData(databaseUser);
        return user;
    };
    return getUserByProviderId;
};
export const getUserFunction = (auth) => {
    const getUser = async (userId) => {
        const databaseUser = await auth.configs.adapter.getUser(userId);
        if (!databaseUser)
            throw new LuciaError("AUTH_INVALID_USER_ID");
        const user = auth.configs.transformUserData(databaseUser);
        return user;
    };
    return getUser;
};
export const getSessionUserFunction = (auth) => {
    const getSessionUser = async (sessionId) => {
        let userSessionData;
        if (auth.configs.adapter.getSessionAndUserBySessionId !== undefined) {
            userSessionData = await auth.configs.adapter.getSessionAndUserBySessionId(sessionId);
        }
        else {
            const sessionData = await auth.configs.adapter.getSession(sessionId);
            if (!sessionData)
                throw new LuciaError("AUTH_INVALID_SESSION_ID");
            const userData = await auth.configs.adapter.getUser(sessionData.user_id);
            if (!userData)
                throw new LuciaError("AUTH_INVALID_SESSION_ID");
            userSessionData = {
                user: userData,
                session: sessionData
            };
        }
        if (!userSessionData)
            throw new LuciaError("AUTH_INVALID_SESSION_ID");
        const { user: databaseUser, session: databaseSession } = userSessionData;
        if (new Date().getTime() > databaseSession.expires)
            throw new LuciaError("AUTH_INVALID_SESSION_ID");
        const user = auth.configs.transformUserData(databaseUser);
        return {
            user,
            session: {
                sessionId: databaseSession.id,
                expires: databaseSession.expires,
                userId: databaseSession.user_id,
                idlePeriodExpires: databaseSession.idle_expires
            }
        };
    };
    return getSessionUser;
};
